@@ -1,5 +1,5 @@
 package CPAN::Perl::Releases;
-$CPAN::Perl::Releases::VERSION = '5.20200717';
+$CPAN::Perl::Releases::VERSION = '5.20200920';
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
 
 use strict;
@@ -264,6 +264,8 @@ our $data =
 "5.32.0-RC1" => { id => 'XSAWYERX' },
 "5.32.0" => { id => 'XSAWYERX' },
 "5.33.0" => { id => 'XSAWYERX' },
+"5.33.1" => { id => 'ETHER' },
+"5.33.2" => { id => 'XSAWYERX' },
 };
 
 sub perl_tarballs {
@@ -332,7 +334,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 5.20200717
+version 5.20200920
 
 =head1 SYNOPSIS
 
